# Project

Project information. This and that. Contributions are very much welcome.

:::{rubric} Operations
:::
```{toctree}
:maxdepth: 1

caveats
```

:::{rubric} Development
:::
```{toctree}
:maxdepth: 1

Changelog <../changes>
Backlog <../backlog>
prior-art
```
